@@ -1,13 +1,12 @@
 import requests
 import re
+from proteus import may_insist_up_to
 from proteus.config import config
 from proteus.logger import logger
 from threading import Timer, Lock
 import certifi
 import json
 import base64
-from functools import wraps
-import time
 
 (AUTH_HOST, REALM, CLIENT_ID, CLIENT_SECRET, REFRESH_GAP, USERNAME, PASSWORD,) = (
     config.AUTH_HOST,
@@ -29,28 +28,6 @@ class RepeatTimer(Timer):
             self.function(*self.args, **self.kwargs)
 
 
-def may_insist_up_to(times, delay_in_secs=0):
-    def wil_retry_if_fails(fn):
-        @wraps(fn)
-        def wrapped(*args, **kwargs):
-            failures = 0
-            while failures < times:
-                try:
-                    return fn(*args, **kwargs)
-                except Exception as error:
-                    failures += 1
-                    if failures > times:
-                        raise error
-                    else:
-                        time.sleep(delay_in_secs)
-            if failures > 0:
-                logger.warning(f"The process tried: {failures} times")
-
-        return wrapped
-
-    return wil_retry_if_fails
-
-
 class OIDC:
     def __init__(
         self,
